==> wonderpush_flutter-1.0.0.tar.gz: README.md <==
<p align="center"><img src="https://cdn.by.wonderpush.com/assets/images/logo/logo-type-512x85.png"></p>

### WonderPush Flutter SDK

Mobile push notification delivery with the WonderPush service. The WonderPush Flutter SDK is compatible with iOS and Android.

[WonderPush](https://www.wonderpush.com) is the most effective way to retain your users and grow your audience while remaining fully GDPR compliant.

With this plugin, integrate push notification in minutes in your hybrid iOS and Android app.

You can automate notifications based on user behavior, create user segments, and customize the subscription process for visitors.

WonderPush offers a 14-day free trial.
After the trial period, you can benefit from unlimited push notifications and all the features from 1 euro per month. There are no limits on the number of push notifications you can send.

Our features include rich formats, automation, realtime analytics, powerful segmentation... All our features are included and you benefit from evolutions without ever having to pay more.

## Company
[WonderPush](https://www.wonderpush.com) is trusted by over 5,000 developers in Europe and Worldwide.

WonderPush never shares your data with third parties. Your data is safe with us and we protect the privacy of your users as if they were ours. Data collected by our SDKs is fully documented and hosted in Europe.

We provide ready-made tools to collect and manage user consent, and let users download or delete all their data.

## Features
* **Automatic notifications** - Automatically send personalized notifications to users that match certain criteria
* **Segmentation** - Send notifications to specific subscribers based on language, tags, events or properties.

* **Real-time Analytics** - See delivery metrics in real time, and watch them as they convert into visits.

* **Advanced dashboard** - Discover the power of push notification automation. Manage segments and campaigns. Invite staff to join your project.

## Installation

See our [Flutter Installation Guide](https://docs.wonderpush.com/docs/flutter-push-notifications).

## Reference

Check out the [**API reference**](https://docs.wonderpush.com/docs/flutter-push-notifications) for a list of available methods. There's also a [dartdoc reference](https://wonderpush.github.io/wonderpush-flutter-sdk/).

## Migrate from OneSignal plugin and others
If you need to be GDPR compliant and you already use a push notification plugin, migrating to WonderPush is easy: all you have to do is add the WonderPush plugin to your app and disable the other plugin.

Once you have the WonderPush plugin on your app, users who install the latest version of your app and have already granted push notification permission will automatically appear among your subscribers without having to subscribe again.


## Change log and releases

See the [**releases page**](https://github.com/wonderpush/wonderpush-flutter-sdk/releases) on GitHub.

Follow our [**announcements**](https://discuss.wonderpush.com/c/announcements) on our community forum.

## Support

Contact support using the **live chat** on your [dashboard](https://dashboard.wonderpush.com/).

Ask for help on our [**community forum**](https://discuss.wonderpush.com/c/support).

Report a bug, file a feature request or send a pull request in the [**issue tracker**](https://github.com/wonderpush/wonderpush-flutter-sdk/issues).

==> wonderpush_flutter-2.0.0.tar.gz: README.md <==
<p align="center"><img src="https://cdn.by.wonderpush.com/assets/images/logo/logo-type-512x85.png"></p>

### WonderPush Flutter SDK

Mobile push notification delivery with the WonderPush service. The WonderPush Flutter SDK is compatible with iOS and Android.

[WonderPush](https://www.wonderpush.com) is the most effective way to retain your users and grow your audience while remaining fully GDPR compliant.

With this plugin, integrate push notification in minutes in your hybrid iOS and Android app.

You can automate notifications based on user behavior, create user segments, and customize the subscription process for visitors.

WonderPush offers a 14-day free trial.
After the trial period, you can benefit from unlimited push notifications and all the features from 1 euro per month. There are no limits on the number of push notifications you can send.

Our features include rich formats, automation, realtime analytics, powerful segmentation... All our features are included and you benefit from evolutions without ever having to pay more.

## Company
[WonderPush](https://www.wonderpush.com) is trusted by over 5,000 developers in Europe and Worldwide.

WonderPush never shares your data with third parties. Your data is safe with us and we protect the privacy of your users as if they were ours. Data collected by our SDKs is fully documented and hosted in Europe.

We provide ready-made tools to collect and manage user consent, and let users download or delete all their data.

## Features
* **Automatic notifications** - Automatically send personalized notifications to users that match certain criteria
* **Segmentation** - Send notifications to specific subscribers based on language, tags, events or properties.

* **Real-time Analytics** - See delivery metrics in real time, and watch them as they convert into visits.

* **Advanced dashboard** - Discover the power of push notification automation. Manage segments and campaigns. Invite staff to join your project.

## Installation

See our [Flutter Installation Guide](https://docs.wonderpush.com/docs/flutter-push-notifications).

## Reference

Check out the [**API reference**](https://docs.wonderpush.com/docs/flutter-push-notifications) for a list of available methods. There's also a [dartdoc reference](https://pub.dev/documentation/wonderpush_flutter/).

## Migrate from OneSignal plugin and others
If you need to be GDPR compliant and you already use a push notification plugin, migrating to WonderPush is easy: all you have to do is add the WonderPush plugin to your app and disable the other plugin.

Once you have the WonderPush plugin on your app, users who install the latest version of your app and have already granted push notification permission will automatically appear among your subscribers without having to subscribe again.


## Change log and releases

See the [**releases page**](https://github.com/wonderpush/wonderpush-flutter-sdk/releases) on GitHub.

Follow our [**announcements**](https://discuss.wonderpush.com/c/announcements) on our community forum.

## Support

Contact support using the **live chat** on your [dashboard](https://dashboard.wonderpush.com/).

Ask for help on our [**community forum**](https://discuss.wonderpush.com/c/support).

Report a bug, file a feature request or send a pull request in the [**issue tracker**](https://github.com/wonderpush/wonderpush-flutter-sdk/issues).
